@@ -37,11 +37,11 @@ App::ZFSCurses::UI::Datasets - Draw a list of ZFS datasets.
 
 =head1 VERSION
 
-Version 1.210.
+Version 1.211.
 
 =cut
 
-our $VERSION = '1.210';
+our $VERSION = '1.211';
 
 =head1 SYNOPSIS
 
@@ -218,7 +218,7 @@ sub draw_buttons {
     push @$buttons,
       {
         -label   => '[ Properties ]',
-        -onpress => \&onpress_show_snapshot_properties
+        -onpress => \&onpress_show_dataset_properties
       };
 
     push @$buttons,
